mod screen_reader;

pub use screen_reader::TailwindScreenReader;
